@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -79,6 +79,7 @@ class GlancesPortsList(object):
                 new_port['timeout'] = timeout
                 new_port['status'] = None
                 new_port['rtt_warning'] = None
+                new_port['indice'] = str('port_0')
                 logger.debug("Add default gateway %s to the static list" % (new_port['host']))
                 ports_list.append(new_port)
 
@@ -121,6 +122,9 @@ class GlancesPortsList(object):
                     # Convert to second
                     new_port['rtt_warning'] = int(new_port['rtt_warning']) / 1000.0
 
+                # Indice
+                new_port['indice'] = 'port_' + str(i)
+
                 # Add the server to the list
                 logger.debug("Add port %s:%s to the static list" % (new_port['host'], new_port['port']))
                 ports_list.append(new_port)
